<?php


namespace Drupal\travolute\ValueObject;


use Carbon\Carbon;
use Drupal\travolute\Model\SearchRequest;

final class AccommodationParameters
{
    private $departure_date;
    private $airport;
    private $departure_offset;
    private $query;
    private $minimum_number_of_stars;
    private $durations;
    private $boardtypes;
    private $occupancy;

    public function __construct($postData)
    {
        $this->occupancy = $postData['occupancy'];

        if (!isset($postData['occupancy'])) {
            $this->occupancy = 2;
        }

        $this->departure_date = new Carbon($postData['departure_date']);
        $this->airport = $postData['airport'];
        $this->departure_offset = 0;
        $this->query = null;
        $this->minimum_number_of_stars = null;
        $this->durations = $postData['duration'];
        $this->boardtypes = $postData['boardType'];
    }

    public function toArray()
    {
        $output = [
            'departure_date' => $this->departure_date->format('Y-m-d'),
            'departure_offset' => $this->departure_offset,
            'occupancy' => $this->occupancy,
            'offset' =>  0,
            'limit' => 20,
        ];

        if (\is_string($this->query)) {
            $output['query'] = $this->query;
        }

        if (\is_int($this->minimum_number_of_stars)) {
            $output['stars'] = $this->minimum_number_of_stars;
        }

        if (\is_array($this->durations)) {
            $output['duration'] = $this->durations;
        }

        if (\is_array($this->airport)) {
            $output['airport'] = $this->airport;
        }

        if (\is_array($this->boardtypes)) {
            $output['boardtype'] = $this->boardtypes;
        }
        return $output;
    }
}
